do

	local CustomVOReplayTime = {
		OnTransportFull = 1,
		OnUnitCapLimitReached = 60,
		ExperimentalDetected = 60,
		ExperimentalBeingBuilt = 5,
		ExperimentalNearlyBuilt = 20,
		ExperimentalBuiltComplete = 5,
		ExperimentalUnitDestroyed = 5,
		FerryPointSet = 5,
		CoordinatedAttackInitiated = 5,
		BaseUnderAttack = 30,
		UnderAttack = 60,
		EnemyForcesDetected = 120,
		NukeArmed = 1,
		EnemyNukeArmed = 1,
		NuclearLaunchInitiated = 1,
		NuclearLaunchDetected = 1,
		BattleshipDestroyed = 5,
		EnemyNavalForcesDetected = 60,
		MassDepleted = 60,
		EnergyDepleted = 60,
		MassCritical = 60,
		EnergyCritical = 60,
		MassDangerous = 300,
		HealthAt = 30,
		Defeated = 5,
		CommanderDestroyed = 60,
		CommanderDetected = 60,
		BaseDetected = 60,
		NukeSiloDetected = 60,
		ProjectileKilled = 1,
	}

	local oldAI = AIBrain
	AIBrain = Class(oldAI) {
	
		GetFactionName = function(self)
			local factions = {'UEF', 'Aeon', 'Cybran'}
			local name = factions[self:GetFactionIndex()]
			return name
		end,
	
		InitializeEconomyState = function(self)
			oldAI.InitializeEconomyState(self)
			self.EconThread = ForkThread(self.EconomyWarningsVO, self)
		end,
		
		OnDefeat = function(self)
			KillThread(self.EconThread)
			if self.VOTable and not self.VOTable['Defeated'] then
				local FactionName = self:GetFactionName()
				local sound = Sound {
					Bank = 'COMPUTER_'..FactionName..'_VO',
					Cue = FactionName..'Computer_Failed_01422',}
				self.VOTable['Defeated'] = ForkThread(self.PlayVOSound, self, sound, 'Defeated')
			end
			oldAI.OnDefeat(self)
		end,
		
		InitializeVO = function(self)
			VOReplayTime = CustomVOReplayTime
			self.IsPlaying = false
			oldAI.InitializeVO(self)
		end,
		
		PlayVOSound = function(self, sound, string)
			if GetFocusArmy() == self:GetArmyIndex() then
				oldAI.PlayVOSound(self, sound, string)
			end
			self.VOTable[string] = nil
		end,
	
		ExperimentalBeingBuilt = function(self,sound)
			if self.VOTable and not self.VOTable['ExperimentalBeingBuilt'] then
				self.VOTable['ExperimentalBeingBuilt'] = ForkThread(self.PlayVOSound, self, sound, 'ExperimentalBeingBuilt')
			end
		end,
	
		ExperimentalNearlyBuilt = function(self,sound)
			if self.VOTable and not self.VOTable['ExperimentalNearlyBuilt'] then
				self.VOTable['ExperimentalNearlyBuilt'] = ForkThread(self.PlayVOSound, self, sound, 'ExperimentalNearlyBuilt')
			end
		end,
	
		ExperimentalBuiltComplete = function(self,sound)
			if self.VOTable and not self.VOTable['ExperimentalBuiltComplete'] then
				self.VOTable['ExperimentalBuiltComplete'] = ForkThread(self.PlayVOSound, self, sound, 'ExperimentalBuiltComplete')
			end
		end,
		
		EnemyNukeArmed = function(self,sound)
			if self.VOTable and not self.VOTable['EnemyNukeArmed'] then
				self.VOTable['EnemyNukeArmed'] = ForkThread(self.PlayVOSound, self, sound, 'EnemyNukeArmed')
			end
		end,
	
		HealthAt = function(self,sound)
			if self.VOTable and not self.VOTable['HealthAt'] then
				self.VOTable['HealthAt'] = ForkThread(self.PlayVOSound, self, sound, 'HealthAt')
			end
		end,
		
		CommanderDestroyed = function(self, sound)
			if self.VOTable and not self.VOTable['CommanderDestroyed'] then
				self.VOTable['CommanderDestroyed'] = ForkThread(self.PlayVOSound, self, sound, 'CommanderDestroyed')
			end
		end,
		
		CommanderDetected = function(self, sound)
			if self.VOTable and not self.VOTable['CommanderDetected'] then
				self.VOTable['CommanderDetected'] = ForkThread(self.PlayVOSound, self, sound, 'CommanderDetected')
			end
		end,
		
		BaseDetected = function(self, sound)
			if self.VOTable and not self.VOTable['BaseDetected'] then
				self.VOTable['BaseDetected'] = ForkThread(self.PlayVOSound, self, sound, 'BaseDetected')
			end
		end,
		
		NukeSiloDetected = function(self, sound)
			if self.VOTable and not self.VOTable['NukeSiloDetected'] then
				self.VOTable['NukeSiloDetected'] = ForkThread(self.PlayVOSound, self, sound, 'NukeSiloDetected')
			end
		end,
		
		ProjectileKilled = function(self, sound)
			if self.VOTable and not self.VOTable['ProjectileKilled'] then
				self.VOTable['ProjectileKilled'] = ForkThread(self.PlayVOSound, self, sound, 'ProjectileKilled')
			end
		end,
	
		EconomyWarningsVO = function(self)
			WaitSeconds(10)
			local AIu = import('/lua/AI/aiutilities.lua')
			while true do
				#if _G.econ_warn_vo == true then
					local Econ = AIu.AIGetEconomyNumbers(self)
					local FactionName = self:GetFactionName()
					if Econ.EnergyStorageRatio == 0 then
						if self.VOTable and not self.VOTable['EnergyDepleted'] then
							local sound = Sound {
								Bank = 'COMPUTER_'..FactionName..'_VO',
								Cue = FactionName..'Computer_Resources_01308',}
							self.VOTable['EnergyDepleted'] = ForkThread(self.PlayVOSound, self, sound, 'EnergyDepleted')
						end
					elseif Econ.EnergyStorageRatio < 0.3 and Econ.EnergyTrend < 0 then
						if self.VOTable and not self.VOTable['EnergyDangerous'] then
							local sound = Sound {
								Bank = 'COMPUTER_'..FactionName..'_VO',
								Cue = FactionName..'Computer_Resources_01304',}
							self.VOTable['EnergyDangerous'] = ForkThread(self.PlayVOSound, self, sound, 'EnergyDangerous')
						end
					end
					if Econ.MassStorageRatio == 0 then
						if self.VOTable and not self.VOTable['MassDepleted'] then
							local sound = Sound {
								Bank = 'COMPUTER_'..FactionName..'_VO',
								Cue = FactionName..'Computer_Resources_01307',}
							self.VOTable['MassDepleted'] = ForkThread(self.PlayVOSound, self, sound, 'MassDepleted')
						end
					elseif Econ.MassStorageRatio < 0.1 and Econ.MassTrend < 0 then
						if self.VOTable and not self.VOTable['MassDangerous'] then
							local sound = Sound {
								Bank = 'COMPUTER_'..FactionName..'_VO',
								Cue = FactionName..'Computer_Resources_01303',}
							self.VOTable['MassDangerous'] = ForkThread(self.PlayVOSound, self, sound, 'MassDangerous')
						end
					elseif Econ.MassStorageRatio > 0.8 and Econ.MassTrend > 0 then
						if self.VOTable and not self.VOTable['MassCritical'] then
							local sound = Sound {
								Bank = 'COMPUTER_'..FactionName..'_VO',
								Cue = FactionName..'Computer_Resources_01305',}
							self.VOTable['MassCritical'] = ForkThread(self.PlayVOSound, self, sound, 'MassCritical')
						end
					end
				#end
				WaitSeconds(1)
			end
		end,
	}
end