#****************************************************************************
#**
#**  File     :  /lua/sim/unit.lua
#**  Author(s):  HX
#**
#**  Summary  : trigger sounds
#**
#****************************************************************************

do 

local oldunit = Unit 

Unit = Class(oldunit) {  

    OnNukeArmed = function(self)
		local bp = self:GetBlueprint()
		local audio = bp.Audio
        if audio then
			local mybrain = self:GetAIBrain()
			if mybrain and ArmyIsCivilian(mybrain:GetArmyIndex()) == false then
				local FactionName = mybrain:GetFactionName()
				for i, brain in ArmyBrains do
					if ArmyIsCivilian(brain:GetArmyIndex()) == false then
						if brain == mybrain then
							if audio['NukeArmed'..FactionName] then
								brain:NukeArmed(audio['NukeArmed'..FactionName])
							end
						elseif IsEnemy(mybrain:GetArmyIndex(), brain:GetArmyIndex()) == true then
							if audio['EnemyNukeArmed'..FactionName] then
								brain:EnemyNukeArmed(audio['EnemyNukeArmed'..FactionName])
							end
						end
					end
				end
			end
        end
    end,
    
    OnDetectedBy = function(self, index)
        if self.DetectedByHooks then
            for k,v in self.DetectedByHooks do
                v(self,index)
            end
        end

        local bp = self:GetBlueprint()
		local audio = bp.Audio
        if audio then
            local brain = ArmyBrains[index]
            if brain and IsEnemy(brain:GetArmyIndex(), self:GetAIBrain():GetArmyIndex()) == true and ArmyIsCivilian(brain:GetArmyIndex()) == false then
				local FactionName = brain:GetFactionName()
				if audio['ExperimentalDetectedBy'..FactionName] then
					brain:ExperimentalDetected(audio['ExperimentalDetectedBy'..FactionName])
				elseif audio['CommanderDetectedBy'..FactionName] then
					brain:CommanderDetected(audio['CommanderDetectedBy'..FactionName])
				elseif audio['NukeSiloDetectedBy'..FactionName] then
					brain:NukeSiloDetected(audio['NukeSiloDetectedBy'..FactionName])
				elseif audio['BaseDetectedBy'..FactionName] then
					brain:BaseDetected(audio['BaseDetectedBy'..FactionName])
				elseif audio['EnemyForcesDetectedBy'..FactionName] then
					brain:EnemyForcesDetected(audio['EnemyForcesDetectedBy'..FactionName])
				end
			end
        end
    end,

	OnDamageBy = function(self,index)
        local bp = self:GetBlueprint()
		local audio = bp.Audio
        if audio then
            local mybrain = self:GetAIBrain()
            if mybrain and ArmyIsCivilian(mybrain:GetArmyIndex()) == false then
				local FactionName = mybrain:GetFactionName()
				if audio['UnderAttack'..FactionName] then
					mybrain:UnderAttack(audio['UnderAttack'..FactionName])
				end
				if EntityCategoryContains(categories.STRUCTURE, self) then
					if audio['BaseUnderAttack'..FactionName] then
						mybrain:BaseUnderAttack(audio['BaseUnderAttack'..FactionName])
					end
				end
				local HealthPercent = self:GetHealthPercent()
				local sound = nil
				if HealthPercent < 0.78 and HealthPercent > 0.72 then
					if audio['HealthAt75'..FactionName] then
						sound = audio['HealthAt75'..FactionName]
					end
				elseif HealthPercent < 0.53 and HealthPercent > 0.47 then
					if audio['HealthAt50'..FactionName] then
						sound = audio['HealthAt50'..FactionName]
					end
				elseif HealthPercent < 0.28 and HealthPercent > 0.22 then
					if audio['HealthAt25'..FactionName] then
						sound = audio['HealthAt25'..FactionName]
					end
				elseif HealthPercent < 0.18 and HealthPercent > 0.12 then
					if audio['HealthAt15'..FactionName] then
						sound = audio['HealthAt15'..FactionName]
					end
				elseif HealthPercent < 0.08 and HealthPercent > 0.02 then
					if audio['HealthAt05'..FactionName] then
						sound = audio['HealthAt05'..FactionName]
					end
				end
				if sound then
					mybrain:HealthAt(sound)
				end
			end
		end
    end,
    
    OnStartBeingBuilt = function(self, builder, layer)
		oldunit.OnStartBeingBuilt(self, builder, layer)
		local bp = self:GetBlueprint()
		local audio = bp.Audio
		local mybrain = self:GetAIBrain()
		for i, brain in ArmyBrains do
			if ArmyIsCivilian(brain:GetArmyIndex()) == false then
				local snd = 0
				local Faction = brain:GetFactionIndex()
				local FactionName = mybrain:GetFactionName()
				if brain == mybrain then
					snd = audio['ExperimentalBeingBuiltByMe'..FactionName]
				elseif IsAlly(mybrain:GetArmyIndex(), brain:GetArmyIndex()) then
					snd = audio['ExperimentalBeingBuiltByAlly'..FactionName]
				else
					snd = audio['ExperimentalBeingBuiltByEnemy'..FactionName]
				end
				if  snd then
					brain:ExperimentalBeingBuilt(snd)
				end
			end
		end
    end,
    
    OnStopBeingBuilt = function(self, builder, layer)
		oldunit.OnStopBeingBuilt(self, builder, layer)
		local bp = self:GetBlueprint()
		local audio = bp.Audio
		local mybrain = self:GetAIBrain()
		local FactionName = mybrain:GetFactionName()
		if FactionName then
			if  audio['ExperimentalBuiltCompleteBy'..FactionName] then
				mybrain:ExperimentalBuiltComplete(audio['ExperimentalBuiltCompleteBy'..FactionName])
			end
		end
	end,
	
    OnKilledVO = function(self)
		local bp = self:GetBlueprint()
		if bp then
			local audio = bp.Audio
			local mybrain = self:GetAIBrain()
			for i, brain in ArmyBrains do
				if ArmyIsCivilian(brain:GetArmyIndex()) == false then
					local snd = 0
					local FactionName = brain:GetFactionName()
					if brain == mybrain then
						if audio['MyExperimentalUnitDestroyed'..FactionName] then
							snd = audio['MyExperimentalUnitDestroyed'..FactionName]
						elseif audio['CommanderDestroyed'..FactionName] then
							snd = audio['MyExperimentalUnitDestroyed'..FactionName]
						elseif audio['UnitDestroyed'..FactionName] then
							snd = audio['UnitDestroyed'..FactionName]
						end
					elseif IsAlly(mybrain:GetArmyIndex(), brain:GetArmyIndex()) then
						snd = audio['AllyExperimentalUnitDestroyed'..FactionName]
					else
						snd = audio['EnemyExperimentalUnitDestroyed'..FactionName]
					end
					if  snd != nil then
						brain:ExperimentalUnitDestroyed(snd)
					end
				end
			end
		end
    end,

} 

end 